@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2020, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2020, Intel Corporation */
 
 /*
  * sync.c -- a module for poolset synchronizing
@@ -54,7 +25,7 @@
 #include "rpmem_ssh.h"
 #endif
 
-#define BB_DATA_STR "offset 0x%llx, length 0x%x, nhealthy %i"
+#define BB_DATA_STR "offset 0x%zx, length 0x%zx, nhealthy %i"
 
 /* defines 'struct bb_vec' - the vector of the 'struct bad_block' structures */
 VEC(bb_vec, struct bad_block);
@@ -248,7 +219,7 @@ sync_recalc_badblocks(struct pool_set *set,
 
 			for (unsigned i = 0; i < phs->bbs.bb_cnt; i++) {
 				LOG(10,
-					"relative bad block #%i: offset %llu, length %u",
+					"relative bad block #%i: offset %zu, length %zu",
 					i,
 					phs->bbs.bbv[i].offset,
 					phs->bbs.bbv[i].length);
@@ -287,7 +258,7 @@ sync_recalc_badblocks(struct pool_set *set,
 				phs->bbs.bbv[i].length = (unsigned)len;
 
 				LOG(10,
-					"absolute bad block #%i: offset 0x%llx, length 0x%x",
+					"absolute bad block #%i: offset 0x%zx, length 0x%zx",
 					i,
 					phs->bbs.bbv[i].offset,
 					phs->bbs.bbv[i].length);
@@ -353,8 +324,8 @@ sync_badblocks_find_healthy_replica(struct part_health_status *phs,
 	unsigned long long end_prev;
 	unsigned long long beg_new;
 	unsigned long long end_new;
-	unsigned len_prev;
-	unsigned len_new;
+	size_t len_prev;
+	size_t len_new;
 
 	size_t size_all = VEC_SIZE(pbbv_all);
 
@@ -596,7 +567,7 @@ sync_badblocks_assign_healthy_replica(struct part_health_status *phs,
 	struct bad_block bb_old;	/* an old element */
 	struct bad_block *pbb_all;	/* current element of bbv_all[] */
 
-	unsigned length_left;
+	size_t length_left;
 
 	struct bb_vec bbv_new = VEC_INITIALIZER;
 
@@ -780,7 +751,7 @@ sync_check_bad_blocks_overlap(struct pool_set *set,
 			ret = 1; /* this bad block cannot be fixed */
 
 			LOG(1,
-				"uncorrectable bad block found: offset 0x%llx, length 0x%x",
+				"uncorrectable bad block found: offset 0x%zx, length 0x%zx",
 				pbb_all->offset, pbb_all->length);
 
 			goto exit;
