@@ -2831,6 +2831,12 @@ function check() {
 			match $option $FILES
 		fi
 	fi
+	# Move logs to build folder
+	LOG_DIR=logs/$TEST/$REAL_FS/$BUILD$MCSTR$PROV$PM
+	if [ ! -d $LOG_DIR ]; then mkdir --parents $LOG_DIR; fi
+	for f in $(get_files ".*[a-zA-Z_]${UNITTEST_NUM}\.log"); do
+		mv -f $f $LOG_DIR/$f
+	done
 }
 
 #
@@ -3539,7 +3545,7 @@ function pmreorder_run_tool()
 #
 function pmreorder_expect_success()
 {
-	ret=$(pmreorder_run_tool "$@")
+	ret=$(pmreorder_run_tool "$@" | tail -n1)
 
 	if [ "$ret" -ne "0" ]; then
 		msg=$(interactive_red STDERR "failed with exit code $ret")
@@ -3561,7 +3567,7 @@ function pmreorder_expect_success()
 #
 function pmreorder_expect_failure()
 {
-	ret=$(pmreorder_run_tool "$@")
+	ret=$(pmreorder_run_tool "$@" | tail -n1)
 
 	if [ "$ret" -eq "0" ]; then
 		msg=$(interactive_red STDERR "succeeded")
